@@ -1,5 +1,6 @@
 use develop_debug::*;
 
+// Standard usage
 #[test]
 fn use_develop_debug() {
     let x = "dear X";
@@ -8,6 +9,7 @@ fn use_develop_debug() {
     let title2 = "balabala...";
 
     develop_debug!(title "example",title2);
+    develop_debug!(step "do something...");
     develop_debug!(var x,say);
     develop_debug!(iter array.iter());
     develop_debug!(done "genius!");
@@ -18,6 +20,7 @@ fn use_develop_debug() {
     );
 }
 
+// Using the shortcut, print the same result as above.
 #[test]
 fn use_develop_debug_shortcut() {
     let x = "dear X";
@@ -26,6 +29,7 @@ fn use_develop_debug_shortcut() {
     let title2 = "balabala...";
 
     dd___title!("example", title2);
+    dd____step!("do something...");
     dd_____var!(x, say);
     dd____iter!(array.iter());
     dd____done!("genius!");
